==> hadoop-client-2.4.1-mapr-4.0.1-20140820.221414-2-javadoc.jar: dist-copynativelibs.sh <==
echo "beginning dist-copynativelibs.sh"
                       BUILD_DIR="/root/hadoop-common/hadoop-client/target"
                      TAR='tar -cf -'
                      UNTAR='tar -xf -'
                       LIB_DIR="${BUILD_DIR}/native/target/usr/local/lib"
                                         echo "checking existence of ${LIB_DIR}..."
                       if [ -d ${LIB_DIR} ] ; then
                                           echo "${LIB_DIR} exists"
                         TARGET_DIR="${BUILD_DIR}/hadoop-client-2.4.1-mapr-4.0.1-SNAPSHOT/lib/native"
                         mkdir -p ${TARGET_DIR}
                         cd ${LIB_DIR}
                         $TAR lib* | (cd ${TARGET_DIR}/; $UNTAR)
                         if [ "false" = "true" ] ; then
                                                 echo "bundle.snappy is true"
                           cd ${snappy.lib}
                          # $TAR *snappy* | (cd ${TARGET_DIR}/; $UNTAR)
                                                 cp *snappy* ${TARGET_DIR}
                         fi
                       fi
                       BIN_DIR="${BUILD_DIR}/bin"
                                         echo "checking existence of ${BIN_DIR}..."
                       if [ -d ${BIN_DIR} ] ; then
                                           echo "${BIN_DIR} exists"
                         TARGET_BIN_DIR="${BUILD_DIR}/hadoop-client-2.4.1-mapr-4.0.1-SNAPSHOT/bin"
                                               echo "making ${TARGET_BIN_DIR}"
                         mkdir -p ${TARGET_BIN_DIR}
                                               echo "entering ${BIN_DIR}"
                         cd ${BIN_DIR}
                        # $TAR * | (cd ${TARGET_BIN_DIR}/; $UNTAR)
                                               cp * ${TARGET_BIN_DIR}
                                               echo "checking bundle.snappy.in.bin..."
                         if [ "false" = "true" ] ; then
                                                 echo "bundle.snappy.in.bin is true"
                           if [ "false" = "true" ] ; then
                                                   echo "bundle.snappy is true"
                             cd ${snappy.lib}
                            # $TAR *snappy* | (cd ${TARGET_BIN_DIR}/; $UNTAR)
                                                       cp *snappy* ${TARGET_BIN_DIR}
                          fi
                        fi
                      fi

==> hadoop-client-2.5.1-mapr-1410-20141010.012503-1-javadoc.jar: dist-copynativelibs.sh <==
echo "beginning dist-copynativelibs.sh"
                       BUILD_DIR="/root/ecosystem/dl/hadoop-common/hadoop-client/target"
                      TAR='tar -cf -'
                      UNTAR='tar -xf -'
                       LIB_DIR="${BUILD_DIR}/native/target/usr/local/lib"
                                         echo "checking existence of ${LIB_DIR}..."
                       if [ -d ${LIB_DIR} ] ; then
                                           echo "${LIB_DIR} exists"
                         TARGET_DIR="${BUILD_DIR}/hadoop-client-2.5.1-mapr-1410-SNAPSHOT/lib/native"
                         mkdir -p ${TARGET_DIR}
                         cd ${LIB_DIR}
                         $TAR lib* | (cd ${TARGET_DIR}/; $UNTAR)
                         if [ "true" = "true" ] ; then
                                                 echo "bundle.snappy is true"
                           cd /usr/local/lib/
                          # $TAR *snappy* | (cd ${TARGET_DIR}/; $UNTAR)
                                                 cp *snappy* ${TARGET_DIR}
                         fi
                       fi
                       BIN_DIR="${BUILD_DIR}/bin"
                                         echo "checking existence of ${BIN_DIR}..."
                       if [ -d ${BIN_DIR} ] ; then
                                           echo "${BIN_DIR} exists"
                         TARGET_BIN_DIR="${BUILD_DIR}/hadoop-client-2.5.1-mapr-1410-SNAPSHOT/bin"
                                               echo "making ${TARGET_BIN_DIR}"
                         mkdir -p ${TARGET_BIN_DIR}
                                               echo "entering ${BIN_DIR}"
                         cd ${BIN_DIR}
                        # $TAR * | (cd ${TARGET_BIN_DIR}/; $UNTAR)
                                               cp * ${TARGET_BIN_DIR}
                                               echo "checking bundle.snappy.in.bin..."
                         if [ "false" = "true" ] ; then
                                                 echo "bundle.snappy.in.bin is true"
                           if [ "true" = "true" ] ; then
                                                   echo "bundle.snappy is true"
                             cd /usr/local/lib/
                            # $TAR *snappy* | (cd ${TARGET_BIN_DIR}/; $UNTAR)
                                                       cp *snappy* ${TARGET_BIN_DIR}
                          fi
                        fi
                      fi
